/* TRConnectionExample.java 
 * 
 * Copyright (c) 2010, Comsec TR Pty. Ltd., Sydney Australia. 
 * All rights reserved. 
 * 
 * No part of this program may be reproduced, stored in a retrieval system 
 * or transmitted in any form or by any means, electronic, mechanical, 
 * recording or otherwise, without the prior written permission of the 
 * author. 
 */ 
package com.arunta.app.remote.example;

import java.net.URI;
import java.net.URISyntaxException;
import java.rmi.RemoteException;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.core.LoggerContext;

import com.arunta.app.bom.SecurityKey;
import com.arunta.app.remote.TRRemoteUtility;
import com.arunta.app.remote.TRSystemServiceRI;
import com.arunta.base.exception.SecurityException;

/** Example which shows how to connect to the TR.
 */
public class TRConnectionExample {

    public static void main(String[] args) {
        
        LoggerContext loggerContext = (LoggerContext) LogManager.getContext(false);
        try {
            loggerContext.setConfigLocation(new URI("log4j2.xml"));
        }
        catch (URISyntaxException e) {
            e.printStackTrace();
            System.exit(-1);
        }

        // From the Remote Manager configuration ...
        final String rmIpAddress = "192.168.4.115";
        final int rmPort = 10010;
        final String trPassword = "0000";

        TRSystemServiceRI trSystemService = null;
        try {
            trSystemService = TRRemoteUtility.getSystemService(rmIpAddress, rmPort);;
        } 
        catch (RemoteException e) {
            e.printStackTrace();
            System.exit(1);
        } 

        try {
            trSystemService.ping();
        } 
        catch (RemoteException e) {
            e.printStackTrace();
            System.exit(1);
        }
		
        SecurityKey securityKey = null;
        try {
            securityKey = trSystemService.logon(trPassword, "example");
        } 
        catch (RemoteException e) {
            e.printStackTrace();
            System.exit(1);
        } 
        catch (SecurityException e) {
            e.printStackTrace();
            System.exit(1);
        }

        System.out.println("GOT SECURITY KEY: " + securityKey.toString());        
	}

}
