package com.arunta.app.remote.example;

import java.util.Hashtable;

import com.arunta.base.audio.codec.Decoder;
import com.arunta.base.audio.codec.DecoderSelector;
import com.arunta.base.audio.streaming.StreamPacket;
import com.arunta.base.audio.streaming.StreamPacketListener;
import com.arunta.base.audio.streaming.StreamControlPacket;
import com.arunta.base.audio.streaming.StreamMediaPacket;

public class TRPlaybackClient implements StreamPacketListener {

    private Hashtable decodersTable;

    public TRPlaybackClient() {
        this.decodersTable = new Hashtable();
    }
    
    public void handlePacket(StreamPacket packet) {
        switch (packet.getPacketType()) {
            case StreamPacket.STREAM_CONTROL: {
                StreamControlPacket scp = (StreamControlPacket)packet;
                switch(scp.getStreamAction())
                {
                    case StreamControlPacket.ADD_STREAM: {
                        System.out.println(
                                "Stream starting. Stream ID: " + scp.getStreamId() + 
                                "\nMedia format: " + scp.getCodeName());
                        
                        Integer key = Integer.valueOf(scp.getStreamId());
                        Decoder decoder =
                            DecoderSelector.getInstance().allocateDecoder(scp.getCodeName());

                        decodersTable.put(key, decoder);
                    }
                    break;
                    case StreamControlPacket.CHANGE_STREAM: {
                        System.out.println(
                                "New media format for stream. Stream ID: " + scp.getStreamId() + 
                                "\nNew media format: " + scp.getCodeName());
                    }
                    break;
                    case StreamControlPacket.REMOVE_STREAM: {
                        System.out.println(
                                "Stream ended. Stream ID: " + scp.getStreamId());
                        
                        Integer key = Integer.valueOf(scp.getStreamId());
                        if (decodersTable.containsKey(key)) {
                            decodersTable.remove(key);
                        }
                    }
                    break;
                }
            }
            break;
            case StreamPacket.STREAM_MEDIA: {
                StreamMediaPacket smp = (StreamMediaPacket)packet;

                Integer key = Integer.valueOf(smp.getStreamId());
                Decoder decoder = 
                    (Decoder) decodersTable.get(key);
                if (decoder == null) {
                    System.out.println("Missing decoder?!?");
                }
                else {
                    byte[] decodedBytes = 
                        new byte[smp.getMediaSamples().length * decoder.getExpansionFactor()];

                    int decodedByteCount = 
                        decoder.decode(smp.getMediaSamples(), 0, smp.getMediaSamples().length, decodedBytes, 0);
                    
                    System.out.println(
                            "Media samples for stream. Stream ID: " + smp.getStreamId() +
                            " Encoded byte count: " + smp.getMediaSamples().length +
                            " Decoded byte count: " + decodedByteCount);
                }
            }
            break;
            default: {
                System.out.println("Unknown streaming packet.");
            }
            break;
        }
    }

}
